@@ -50,16 +50,35 @@ impl super::Kubectl {
         api::Api::<T>::namespaced(client, namespace)
     }
 
+    pub fn configmaps<'a>(
+        &self,
+        namespace: impl Into<Option<&'a str>>,
+    ) -> api::Api<corev1::ConfigMap> {
+        if let Some(namespace) = namespace.into() {
+            self.namespaced_api::<corev1::ConfigMap>(namespace)
+        } else {
+            self.default_namespaced_api::<corev1::ConfigMap>()
+        }
+    }
+
+    pub fn secrets<'a>(&self, namespace: impl Into<Option<&'a str>>) -> api::Api<corev1::Secret> {
+        if let Some(namespace) = namespace.into() {
+            self.namespaced_api::<corev1::Secret>(namespace)
+        } else {
+            self.default_namespaced_api::<corev1::Secret>()
+        }
+    }
+
+    pub fn crds(&self) -> api::Api<apiextensionsv1::CustomResourceDefinition> {
+        self.api::<apiextensionsv1::CustomResourceDefinition>()
+    }
+
     pub async fn get_secret(&self, name: &str) -> kube::Result<corev1::Secret> {
-        self.default_namespaced_api::<corev1::Secret>()
-            .get(name)
-            .await
+        self.secrets(None).get(name).await
     }
 
     pub async fn get_config_map(&self, name: &str) -> kube::Result<corev1::ConfigMap> {
-        self.default_namespaced_api::<corev1::ConfigMap>()
-            .get(name)
-            .await
+        self.configmaps(None).get(name).await
     }
 
     pub async fn put_config_map(
@@ -67,7 +86,6 @@ impl super::Kubectl {
         name: &str,
         data: BTreeMap<String, String>,
     ) -> kube::Result<corev1::ConfigMap> {
-        let configmaps = self.default_namespaced_api::<corev1::ConfigMap>();
         let mut cm: corev1::ConfigMap = json::from_value(json::json!(
             {
                 "metadata": {
@@ -79,6 +97,7 @@ impl super::Kubectl {
         .expect("Failed to create ConfigMap");
 
         let pp = self.post_params();
+        let configmaps = self.configmaps(None);
 
         let cm = if let Ok(existing) = configmaps.get(name).await {
             cm.meta_mut().resource_version = existing.resource_version();
@@ -89,4 +108,9 @@ impl super::Kubectl {
 
         Ok(cm)
     }
+
+    pub async fn list_crds(&self) -> kube::Result<Vec<apiextensionsv1::CustomResourceDefinition>> {
+        let lp = self.list_params();
+        self.crds().list(&lp).await.map(|object| object.items)
+    }
 }
